
## nocov start

pkgenv <- new.env(parent = emptyenv())

pkgenv$r_versions <- list(
  list(version = "0.60",   date = "1997-12-04T08:47:58.000000Z"),
  list(version = "0.61",   date = "1997-12-21T13:09:22.000000Z"),
  list(version = "0.61.1", date = "1998-01-10T00:31:55.000000Z"),
  list(version = "0.61.2", date = "1998-03-14T19:25:55.000000Z"),
  list(version = "0.61.3", date = "1998-05-02T07:58:17.000000Z"),
  list(version = "0.62",   date = "1998-06-14T12:56:20.000000Z"),
  list(version = "0.62.1", date = "1998-06-14T22:13:25.000000Z"),
  list(version = "0.62.2", date = "1998-07-10T11:13:45.000000Z"),
  list(version = "0.62.3", date = "1998-08-28T09:02:19.000000Z"),
  list(version = "0.62.4", date = "1998-10-23T12:08:41.000000Z"),
  list(version = "0.63",   date = "1998-11-13T14:37:19.000000Z"),
  list(version = "0.63.1", date = "1998-12-04T13:06:28.000000Z"),
  list(version = "0.63.2", date = "1999-01-11T12:55:50.000000Z"),
  list(version = "0.63.3", date = "1999-03-05T14:27:14.000000Z"),
  list(version = "0.64",   date = "1999-04-07T13:19:41.000000Z"),
  list(version = "0.64.1", date = "1999-05-07T13:25:43.000000Z"),
  list(version = "0.64.2", date = "1999-07-02T12:23:15.000000Z"),
  list(version = "0.65",   date = "1999-08-27T10:29:29.000000Z"),
  list(version = "0.65.1", date = "1999-10-06T12:13:04.000000Z"),
  list(version = "0.90",   date = "1999-11-22T12:25:14.000000Z"),
  list(version = "0.90.1", date = "1999-12-15T12:29:07.000000Z"),
  list(version = "0.99",   date = "2000-02-07T11:24:50.000000Z"),
  list(version = "1.0",    date = "2000-02-29T08:55:23.000000Z"),
  list(version = "1.0.1",  date = "2000-04-14T08:44:18.000000Z"),
  list(version = "1.1",    date = "2000-06-15T08:43:21.000000Z"),
  list(version = "1.1.1",  date = "2000-08-15T08:54:18.000000Z"),
  list(version = "1.2",    date = "2000-12-15T10:19:25.000000Z"),
  list(version = "1.2.1",  date = "2001-01-15T10:18:01.000000Z"),
  list(version = "1.2.2",  date = "2001-02-26T12:43:25.000000Z"),
  list(version = "1.2.3",  date = "2001-04-26T11:29:47.000000Z"),
  list(version = "1.3",    date = "2001-06-22T10:41:02.000000Z"),
  list(version = "1.3.1" , date = "2001-08-31T12:45:52.000000Z"),
  list(version = "1.4"   , date = "2001-12-19T10:14:54.000000Z"),
  list(version = "1.4.1",  date = "2002-01-30T11:57:35.000000Z"),
  list(version = "1.5.0",  date = "2002-04-29T10:01:26.000000Z"),
  list(version = "1.5.1",  date = "2002-06-17T11:20:33.000000Z"),
  list(version = "1.6.0",  date = "2002-10-01T10:06:31.000000Z"),
  list(version = "1.6.1",  date = "2002-11-01T10:33:17.000000Z"),
  list(version = "1.6.2",  date = "2003-01-10T15:34:34.000000Z"),
  list(version = "1.7.0",  date = "2003-04-16T12:58:07.000000Z"),
  list(version = "1.7.1",  date = "2003-06-16T09:54:39.000000Z"),
  list(version = "1.8.0",  date = "2003-10-08T11:13:59.000000Z"),
  list(version = "1.8.1",  date = "2003-11-21T12:00:21.000000Z"),
  list(version = "1.9.0",  date = "2004-04-12T10:36:38.000000Z"),
  list(version = "1.9.1",  date = "2004-06-21T11:09:39.000000Z"),
  list(version = "2.0.0",  date = "2004-10-04T14:24:38.899055Z"),
  list(version = "2.0.1",  date = "2004-11-15T14:16:30.003793Z"),
  list(version = "2.1.0",  date = "2005-04-18T22:26:33.135566Z"),
  list(version = "2.1.1",  date = "2005-06-20T09:27:13.106513Z"),
  list(version = "2.2.0",  date = "2005-10-06T10:22:14.085752Z"),
  list(version = "2.2.1",  date = "2005-12-20T10:35:21.589612Z"),
  list(version = "2.3.0",  date = "2006-04-24T10:37:20.758200Z"),
  list(version = "2.3.1",  date = "2006-06-01T08:25:33.882724Z"),
  list(version = "2.4.0",  date = "2006-10-03T10:15:04.354469Z"),
  list(version = "2.4.1",  date = "2006-12-18T09:49:23.725060Z"),
  list(version = "2.5.0",  date = "2007-04-24T09:41:43.361786Z"),
  list(version = "2.5.1",  date = "2007-06-28T11:17:06.374019Z"),
  list(version = "2.6.0",  date = "2007-10-03T09:02:53.434461Z"),
  list(version = "2.6.1",  date = "2007-11-26T14:14:04.408327Z"),
  list(version = "2.6.2",  date = "2008-02-08T11:10:05.737877Z"),
  list(version = "2.7.0",  date = "2008-04-22T07:45:29.665494Z"),
  list(version = "2.7.1",  date = "2008-06-23T07:44:32.518990Z"),
  list(version = "2.7.2",  date = "2008-08-25T08:53:56.807981Z"),
  list(version = "2.8.0",  date = "2008-10-20T09:24:01.015723Z"),
  list(version = "2.8.1",  date = "2008-12-22T09:03:17.828643Z"),
  list(version = "2.9.0",  date = "2009-04-17T08:32:48.144754Z"),
  list(version = "2.9.1",  date = "2009-06-26T12:10:57.017685Z"),
  list(version = "2.9.2",  date = "2009-08-24T08:22:34.737538Z"),
  list(version = "2.10.0", date = "2009-10-26T09:02:22.255015Z"),
  list(version = "2.10.1", date = "2009-12-14T10:28:24.741988Z"),
  list(version = "2.11.0", date = "2010-04-22T08:11:21.939620Z"),
  list(version = "2.11.1", date = "2010-05-31T08:10:25.280185Z"),
  list(version = "2.12.0", date = "2010-10-15T08:41:57.974589Z"),
  list(version = "2.12.1", date = "2010-12-16T09:12:04.607865Z"),
  list(version = "2.12.2", date = "2011-02-25T11:07:19.316500Z"),
  list(version = "2.13.0", date = "2011-04-13T08:31:27.165034Z"),
  list(version = "2.13.1", date = "2011-07-08T09:37:08.653178Z"),
  list(version = "2.13.2", date = "2011-09-30T07:05:56.091789Z"),
  list(version = "2.14.0", date = "2011-10-31T08:09:09.353781Z"),
  list(version = "2.14.1", date = "2011-12-22T08:10:18.809127Z"),
  list(version = "2.14.2", date = "2012-02-29T08:10:10.445478Z"),
  list(version = "2.15.0", date = "2012-03-30T07:16:05.708046Z"),
  list(version = "2.15.1", date = "2012-06-22T07:09:44.415136Z"),
  list(version = "2.15.2", date = "2012-10-26T07:11:16.605580Z"),
  list(version = "2.15.3", date = "2013-03-01T08:28:29.088755Z"),
  list(version = "3.0.0",  date = "2013-04-03T07:12:36.801147Z"),
  list(version = "3.0.1",  date = "2013-05-16T07:11:33.885209Z"),
  list(version = "3.0.2",  date = "2013-09-25T07:11:09.016418Z"),
  list(version = "3.0.3",  date = "2014-03-06T08:12:33.995105Z"),
  list(version = "3.1.0",  date = "2014-04-10T07:11:10.831155Z"),
  list(version = "3.1.1",  date = "2014-07-10T07:11:09.316022Z"),
  list(version = "3.1.2",  date = "2014-10-31T08:11:32.082768Z"),
  list(version = "3.1.3",  date = "2015-03-09T08:12:20.229070Z"),
  list(version = "3.2.0",  date = "2015-04-16T07:13:33.144514Z"),
  list(version = "3.2.1",  date = "2015-06-18T07:15:04.589869Z"),
  list(version = "3.2.2",  date = "2015-08-14T07:13:18.272871Z"),
  list(version = "3.2.3",  date = "2015-12-10T08:13:08.415370Z"),
  list(version = "3.2.4",  date = "2016-03-10T08:15:45.901354Z"),
  list(version = "3.2.5",  date = "2016-04-14T15:59:38.833914Z"),
  list(version = "3.3.0",  date = "2016-05-03T07:13:28.102867Z"),
  list(version = "3.3.1",  date = "2016-06-21T07:21:38.894907Z"),
  list(version = "3.3.2",  date = "2016-10-31T08:13:15.868949Z"),
  list(version = "3.3.3",  date = "2017-03-06T08:16:31.646592Z"),
  list(version = "3.4.0",  date = "2017-04-21T07:14:45.366247Z"),
  list(version = "3.4.1",  date = "2017-06-30T07:04:11.824142Z"),
  list(version = "3.4.2",  date = "2017-09-28T07:04:35.796221Z"),
  list(version = "3.4.3",  date = "2017-11-30T08:05:05.204665Z"),
  list(version = "3.4.4",  date = "2018-03-15T08:04:27.234564Z"),
  list(version = "3.5.0",  date = "2018-04-23T07:04:38.341063Z"),
  list(version = "3.5.1",  date = "2018-07-02T07:04:31.629927Z"),
  list(version = "3.5.2",  date = "2018-12-20T08:04:40.536010Z"),
  list(version = "3.5.3",  date = "2019-03-11T08:04:49.379300Z"),
  list(version = "3.6.0",  date = "2019-04-26T07:05:03.899333Z"),
  list(version = "3.6.1",  date = "2019-07-05T07:05:03.918895Z"),
  list(version = "3.6.2",  date = "2019-12-12T08:05:03.679160Z"),
  list(version = "3.6.3",  date = "2020-02-29T08:05:16.744223Z"),
  list(version = "4.0.0",  date = "2020-04-24T07:05:34.612930Z"),
  list(version = "4.0.1",  date = "2020-06-06T07:05:16.469439Z"),
  list(version = "4.0.2",  date = "2020-06-22T07:05:19.236082Z"),
  list(version = "4.0.3",  date = "2020-10-10T07:05:24.661746Z")
)

pkgenv$rspm_versions <- c(
  `2017-10-10T00:00:00Z` = "5", `2017-10-25T00:00:00Z` = "6",
  `2017-10-30T00:00:00Z` = "7", `2017-11-01T00:00:00Z` = "8",
  `2017-11-03T00:00:00Z` = "9", `2017-11-07T00:00:00Z` = "10",
  `2017-11-08T00:00:00Z` = "11", `2017-11-13T00:00:00Z` = "12",
  `2017-11-15T00:00:00Z` = "13", `2017-11-16T00:00:00Z` = "14",
  `2017-11-17T00:00:00Z` = "15", `2017-11-20T00:00:00Z` = "16",
  `2017-11-22T00:00:00Z` = "17", `2017-11-27T00:00:00Z` = "18",
  `2017-11-28T00:00:00Z` = "19", `2017-11-29T00:00:00Z` = "20",
  `2017-11-30T00:00:00Z` = "21", `2017-12-01T00:00:00Z` = "22",
  `2017-12-06T00:00:00Z` = "23", `2017-12-08T00:00:00Z` = "24",
  `2017-12-11T00:00:00Z` = "25", `2017-12-12T00:00:00Z` = "26",
  `2017-12-13T00:00:00Z` = "27", `2017-12-19T00:00:00Z` = "28",
  `2017-12-20T00:00:00Z` = "29", `2018-01-04T00:00:00Z` = "30",
  `2018-01-05T00:00:00Z` = "31", `2018-01-08T00:00:00Z` = "32",
  `2018-01-11T00:00:00Z` = "33", `2018-01-18T00:00:00Z` = "34",
  `2018-01-22T00:00:00Z` = "35", `2018-01-29T00:00:00Z` = "36",
  `2018-01-31T00:00:00Z` = "37", `2018-02-05T00:00:00Z` = "38",
  `2018-02-15T00:00:00Z` = "39", `2018-02-23T00:00:00Z` = "40",
  `2018-03-05T00:00:00Z` = "41", `2018-03-08T00:00:00Z` = "42",
  `2018-03-13T00:00:00Z` = "43", `2018-03-15T00:00:00Z` = "44",
  `2018-03-20T00:00:00Z` = "45", `2018-03-21T00:00:00Z` = "46",
  `2018-03-23T00:00:00Z` = "47", `2018-03-27T00:00:00Z` = "48",
  `2018-03-28T00:00:00Z` = "49", `2018-04-03T00:00:00Z` = "50",
  `2018-04-10T00:00:00Z` = "51", `2018-04-18T00:00:00Z` = "52",
  `2018-04-23T00:00:00Z` = "53", `2018-04-26T00:00:00Z` = "54",
  `2018-04-30T00:00:00Z` = "55", `2018-05-03T00:00:00Z` = "56",
  `2018-05-07T00:00:00Z` = "57", `2018-05-08T00:00:00Z` = "58",
  `2018-05-10T00:00:00Z` = "59", `2018-05-14T00:00:00Z` = "60",
  `2018-05-17T00:00:00Z` = "61", `2018-05-21T00:00:00Z` = "62",
  `2018-05-24T00:00:00Z` = "63", `2018-05-30T00:00:00Z` = "64",
  `2018-06-04T00:00:00Z` = "65", `2018-06-07T00:00:00Z` = "66",
  `2018-06-11T00:00:00Z` = "67", `2018-06-15T00:00:00Z` = "68",
  `2018-06-18T00:00:00Z` = "69", `2018-06-21T00:00:00Z` = "70",
  `2018-06-25T00:00:00Z` = "71", `2018-06-28T00:00:00Z` = "72",
  `2018-07-02T00:00:00Z` = "73", `2018-07-05T00:00:00Z` = "74",
  `2018-07-09T00:00:00Z` = "75", `2018-07-13T00:00:00Z` = "76",
  `2018-07-16T00:00:00Z` = "77", `2018-07-19T00:00:00Z` = "78",
  `2018-07-23T00:00:00Z` = "79", `2018-07-26T00:00:00Z` = "80",
  `2018-07-30T00:00:00Z` = "81", `2018-08-02T00:00:00Z` = "82",
  `2018-08-06T00:00:00Z` = "83", `2018-08-09T00:00:00Z` = "84",
  `2018-08-14T00:00:00Z` = "85", `2018-08-16T00:00:00Z` = "86",
  `2018-08-20T00:00:00Z` = "87", `2018-08-21T00:00:00Z` = "88",
  `2018-08-22T00:00:00Z` = "89", `2018-08-23T00:00:00Z` = "90",
  `2018-08-24T00:00:00Z` = "91", `2018-08-27T00:00:00Z` = "92",
  `2018-08-30T00:00:00Z` = "93", `2018-09-04T00:00:00Z` = "94",
  `2018-09-06T00:00:00Z` = "95", `2018-09-10T00:00:00Z` = "96",
  `2018-09-13T00:00:00Z` = "97", `2018-09-17T00:00:00Z` = "98",
  `2018-09-20T00:00:00Z` = "99", `2018-09-24T00:00:00Z` = "100",
  `2018-09-27T00:00:00Z` = "101", `2018-10-01T00:00:00Z` = "102",
  `2018-10-04T00:00:00Z` = "103", `2018-10-08T00:00:00Z` = "104",
  `2018-10-11T00:00:00Z` = "105", `2018-10-15T00:00:00Z` = "106",
  `2018-10-18T00:00:00Z` = "107", `2018-10-22T00:00:00Z` = "108",
  `2018-10-25T00:00:00Z` = "109", `2018-10-29T00:00:00Z` = "110",
  `2018-11-01T00:00:00Z` = "111", `2018-11-05T00:00:00Z` = "112",
  `2018-11-08T00:00:00Z` = "113", `2018-11-13T00:00:00Z` = "114",
  `2018-11-15T00:00:00Z` = "115", `2018-11-19T00:00:00Z` = "116",
  `2018-11-26T00:00:00Z` = "117", `2018-11-28T00:00:00Z` = "118",
  `2018-11-29T00:00:00Z` = "119", `2018-12-03T00:00:00Z` = "120",
  `2018-12-06T00:00:00Z` = "121", `2018-12-10T00:00:00Z` = "122",
  `2018-12-11T00:00:00Z` = "123", `2018-12-12T00:00:00Z` = "124",
  `2018-12-13T00:00:00Z` = "125", `2018-12-17T00:00:00Z` = "126",
  `2018-12-20T00:00:00Z` = "127", `2018-12-24T00:00:00Z` = "128",
  `2018-12-27T00:00:00Z` = "129", `2018-12-28T00:00:00Z` = "130",
  `2018-12-31T00:00:00Z` = "131", `2019-01-03T00:00:00Z` = "132",
  `2019-01-07T00:00:00Z` = "133", `2019-01-08T00:00:00Z` = "134",
  `2019-01-10T00:00:00Z` = "135", `2019-01-14T00:00:00Z` = "136",
  `2019-01-17T00:00:00Z` = "137", `2019-01-22T00:00:00Z` = "138",
  `2019-01-25T00:00:00Z` = "139", `2019-01-29T00:00:00Z` = "140",
  `2019-02-01T00:00:00Z` = "141", `2019-02-05T00:00:00Z` = "142",
  `2019-02-07T00:00:00Z` = "143", `2019-02-11T00:00:00Z` = "144",
  `2019-02-14T00:00:00Z` = "145", `2019-02-20T00:00:00Z` = "146",
  `2019-02-25T00:00:00Z` = "147", `2019-02-28T00:00:00Z` = "148",
  `2019-03-04T00:00:00Z` = "149", `2019-03-07T00:00:00Z` = "150",
  `2019-03-11T00:00:00Z` = "151", `2019-03-14T00:00:00Z` = "152",
  `2019-03-18T00:00:00Z` = "153", `2019-03-21T00:00:00Z` = "154",
  `2019-03-25T00:00:00Z` = "155", `2019-03-28T00:00:00Z` = "156",
  `2019-04-01T00:00:00Z` = "157", `2019-04-04T00:00:00Z` = "158",
  `2019-04-08T00:00:00Z` = "159", `2019-04-09T00:00:00Z` = "160",
  `2019-04-11T00:00:00Z` = "161", `2019-04-16T00:00:00Z` = "162",
  `2019-04-18T00:00:00Z` = "163", `2019-04-22T00:00:00Z` = "164",
  `2019-04-25T00:00:00Z` = "165", `2019-04-29T00:00:00Z` = "166",
  `2019-05-02T00:00:00Z` = "167", `2019-05-06T00:00:00Z` = "168",
  `2019-05-07T00:00:00Z` = "169", `2019-05-09T00:00:00Z` = "170",
  `2019-05-13T00:00:00Z` = "171", `2019-05-15T00:00:00Z` = "172",
  `2019-05-16T00:00:00Z` = "173", `2019-05-22T00:00:00Z` = "174",
  `2019-05-24T00:00:00Z` = "175", `2019-05-28T00:00:00Z` = "176",
  `2019-05-30T00:00:00Z` = "177", `2019-06-03T00:00:00Z` = "178",
  `2019-06-06T00:00:00Z` = "179", `2019-06-10T00:00:00Z` = "180",
  `2019-06-13T00:00:00Z` = "181", `2019-06-17T00:00:00Z` = "182",
  `2019-06-20T00:00:00Z` = "183", `2019-06-24T00:00:00Z` = "184",
  `2019-07-01T00:00:00Z` = "185", `2019-07-07T00:00:00Z` = "186",
  `2019-07-08T00:00:00Z` = "187", `2019-07-11T00:00:00Z` = "188",
  `2019-07-15T00:00:00Z` = "189", `2019-07-18T00:00:00Z` = "190",
  `2019-07-22T00:00:00Z` = "191", `2019-07-23T00:00:00Z` = "192",
  `2019-07-25T00:00:00Z` = "193", `2019-07-26T00:00:00Z` = "194",
  `2019-07-29T00:00:00Z` = "195", `2019-08-01T00:00:00Z` = "196",
  `2019-08-05T00:00:00Z` = "197", `2019-08-08T00:00:00Z` = "198",
  `2019-08-12T00:00:00Z` = "199", `2019-08-15T00:00:00Z` = "200",
  `2019-08-19T00:00:00Z` = "201", `2019-08-22T00:00:00Z` = "202",
  `2019-08-23T00:00:00Z` = "203", `2019-08-26T00:00:00Z` = "204",
  `2019-08-29T00:00:00Z` = "205", `2019-09-02T00:00:00Z` = "206",
  `2019-09-05T00:00:00Z` = "207", `2019-09-09T00:00:00Z` = "208",
  `2019-09-12T00:00:00Z` = "209", `2019-09-16T00:00:00Z` = "210",
  `2019-09-19T00:00:00Z` = "211", `2019-09-21T00:00:00Z` = "212",
  `2019-09-23T00:00:00Z` = "213", `2019-09-26T00:00:00Z` = "214",
  `2019-09-30T00:00:00Z` = "215", `2019-10-03T00:00:00Z` = "216",
  `2019-10-07T00:00:00Z` = "217", `2019-10-10T00:00:00Z` = "218",
  `2019-10-14T00:00:00Z` = "219", `2019-10-17T00:00:00Z` = "220",
  `2019-10-21T00:00:00Z` = "221", `2019-10-24T00:00:00Z` = "222",
  `2019-10-28T00:00:00Z` = "223", `2019-10-31T00:00:00Z` = "224",
  `2019-11-04T00:00:00Z` = "225", `2019-11-07T00:00:00Z` = "226",
  `2019-11-12T00:00:00Z` = "227", `2019-11-13T00:00:00Z` = "228",
  `2019-11-14T00:00:00Z` = "229", `2019-11-18T00:00:00Z` = "230",
  `2019-11-21T00:00:00Z` = "231", `2019-11-25T00:00:00Z` = "232",
  `2019-12-02T00:00:00Z` = "233", `2019-12-05T00:00:00Z` = "234",
  `2019-12-10T00:00:00Z` = "235", `2019-12-12T00:00:00Z` = "236",
  `2019-12-16T00:00:00Z` = "237", `2019-12-19T00:00:00Z` = "238",
  `2020-01-06T00:00:00Z` = "239", `2020-01-08T00:00:00Z` = "240",
  `2020-01-09T00:00:00Z` = "241", `2020-01-13T00:00:00Z` = "242",
  `2020-01-14T00:00:00Z` = "243", `2020-01-16T00:00:00Z` = "244",
  `2020-01-21T00:00:00Z` = "245", `2020-01-23T00:00:00Z` = "246",
  `2020-01-27T00:00:00Z` = "247", `2020-01-29T00:00:00Z` = "248",
  `2020-01-30T00:00:00Z` = "249", `2020-02-03T00:00:00Z` = "250",
  `2020-02-05T00:00:00Z` = "251", `2020-02-06T00:00:00Z` = "252",
  `2020-02-10T00:00:00Z` = "253", `2020-02-13T00:00:00Z` = "254",
  `2020-02-17T00:00:00Z` = "255", `2020-02-20T00:00:00Z` = "256",
  `2020-02-24T00:00:00Z` = "257", `2020-02-27T00:00:00Z` = "258",
  `2020-03-02T00:00:00Z` = "259", `2020-03-05T00:00:00Z` = "260",
  `2020-03-09T00:00:00Z` = "261", `2020-03-12T00:00:00Z` = "262",
  `2020-03-16T00:00:00Z` = "263", `2020-03-19T00:00:00Z` = "264",
  `2020-03-23T00:00:00Z` = "265", `2020-03-26T00:00:00Z` = "266",
  `2020-03-30T00:00:00Z` = "267", `2020-04-02T00:00:00Z` = "268",
  `2020-04-06T00:00:00Z` = "269", `2020-04-09T00:00:00Z` = "270",
  `2020-04-13T00:00:00Z` = "271", `2020-04-16T00:00:00Z` = "272",
  `2020-04-20T00:00:00Z` = "273", `2020-04-23T00:00:00Z` = "275",
  `2020-04-27T00:00:00Z` = "276", `2020-04-30T00:00:00Z` = "277",
  `2020-05-04T00:00:00Z` = "278", `2020-05-07T00:00:00Z` = "279",
  `2020-05-11T00:00:00Z` = "280", `2020-05-14T00:00:00Z` = "281",
  `2020-05-15T00:00:00Z` = "282", `2020-05-18T00:00:00Z` = "283",
  `2020-05-21T00:00:00Z` = "284", `2020-05-26T00:00:00Z` = "285",
  `2020-05-28T00:00:00Z` = "288", `2020-06-01T00:00:00Z` = "289",
  `2020-06-04T00:00:00Z` = "290", `2020-06-08T00:00:00Z` = "291",
  `2020-06-11T00:00:00Z` = "292", `2020-06-15T00:00:00Z` = "293",
  `2020-06-18T00:00:00Z` = "294", `2020-06-22T00:00:00Z` = "295",
  `2020-06-25T00:00:00Z` = "296", `2020-06-29T00:00:00Z` = "297",
  `2020-07-02T00:00:00Z` = "298", `2020-07-06T00:00:00Z` = "299",
  `2020-07-09T00:00:00Z` = "300", `2020-07-13T00:00:00Z` = "301",
  `2020-07-16T00:00:00Z` = "302", `2020-07-20T00:00:00Z` = "303",
  `2020-07-23T00:00:00Z` = "304", `2020-07-27T00:00:00Z` = "305",
  `2020-07-30T00:00:00Z` = "306", `2020-08-03T00:00:00Z` = "307",
  `2020-08-06T00:00:00Z` = "308", `2020-08-10T00:00:00Z` = "309",
  `2020-08-13T00:00:00Z` = "310", `2020-08-17T00:00:00Z` = "311",
  `2020-08-20T00:00:00Z` = "312", `2020-08-21T00:00:00Z` = "313",
  `2020-08-24T00:00:00Z` = "314", `2020-08-27T00:00:00Z` = "315",
  `2020-08-31T00:00:00Z` = "316", `2020-09-01T00:00:00Z` = "317",
  `2020-09-02T00:00:00Z` = "318", `2020-09-03T00:00:00Z` = "319",
  `2020-09-04T00:00:00Z` = "320", `2020-09-08T00:00:00Z` = "321",
  `2020-09-09T00:00:00Z` = "322", `2020-09-10T00:00:00Z` = "323",
  `2020-09-11T00:00:00Z` = "324", `2020-09-14T00:00:00Z` = "325",
  `2020-09-15T00:00:00Z` = "326", `2020-09-16T00:00:00Z` = "327",
  `2020-09-17T00:00:00Z` = "328", `2020-09-18T00:00:00Z` = "329",
  `2020-09-21T00:00:00Z` = "330", `2020-09-22T00:00:00Z` = "331",
  `2020-09-23T00:00:00Z` = "332", `2020-09-24T00:00:00Z` = "333",
  `2020-09-25T00:00:00Z` = "334", `2020-09-28T00:00:00Z` = "335",
  `2020-09-29T00:00:00Z` = "336", `2020-09-30T00:00:00Z` = "337",
  `2020-10-01T00:00:00Z` = "338", `2020-10-02T00:00:00Z` = "339",
  `2020-10-05T00:00:00Z` = "340", `2020-10-06T00:00:00Z` = "341",
  `2020-10-07T00:00:00Z` = "342", `2020-10-09T00:00:00Z` = "343",
  `2020-10-13T00:00:00Z` = "344", `2020-10-14T00:00:00Z` = "345",
  `2020-10-15T00:00:00Z` = "346", `2020-10-16T00:00:00Z` = "347",
  `2020-10-19T00:00:00Z` = "348", `2020-10-20T00:00:00Z` = "349",
  `2020-10-21T00:00:00Z` = "350", `2020-10-22T00:00:00Z` = "351",
  `2020-10-23T00:00:00Z` = "352", `2020-10-26T00:00:00Z` = "353",
  `2020-10-27T00:00:00Z` = "354", `2020-10-28T00:00:00Z` = "355",
  `2020-10-29T00:00:00Z` = "356", `2020-11-02T00:00:00Z` = "357",
  `2020-11-03T00:00:00Z` = "358", `2020-11-04T00:00:00Z` = "359",
  `2020-11-05T00:00:00Z` = "360", `2020-11-06T00:00:00Z` = "361",
  `2020-11-09T00:00:00Z` = "362", `2020-11-10T00:00:00Z` = "363",
  `2020-11-11T00:00:00Z` = "364", `2020-11-12T00:00:00Z` = "365",
  `2020-11-13T00:00:00Z` = "366", `2020-11-17T00:00:00Z` = "367",
  `2020-11-18T00:00:00Z` = "368", `2020-11-19T00:00:00Z` = "369",
  `2020-11-20T00:00:00Z` = "371", `2020-11-23T00:00:00Z` = "372",
  `2020-11-24T00:00:00Z` = "373", `2020-11-25T00:00:00Z` = "374",
  `2020-11-26T00:00:00Z` = "375", `2020-11-27T00:00:00Z` = "376",
  `2020-11-30T00:00:00Z` = "2658", `2020-12-01T00:00:00Z` = "16803",
  `2020-12-02T00:00:00Z` = "36893", `2020-12-03T00:00:00Z` = "55500",
  `2020-12-04T00:00:00Z` = "72624", `2020-12-07T00:00:00Z` = "124693",
  `2020-12-08T00:00:00Z` = "147771", `2020-12-09T00:00:00Z` = "164169",
  `2020-12-10T00:00:00Z` = "181268", `2020-12-11T00:00:00Z` = "196169",
  `2020-12-14T00:00:00Z` = "252737", `2020-12-15T00:00:00Z` = "267651",
  `2020-12-16T00:00:00Z` = "287740", `2020-12-17T00:00:00Z` = "304084",
  `2020-12-18T00:00:00Z` = "320454", `2020-12-21T00:00:00Z` = "374083",
  `2020-12-22T00:00:00Z` = "394182", `2020-12-23T00:00:00Z` = "410586",
  `2020-12-28T00:00:00Z` = "499871", `2020-12-30T00:00:00Z` = "535602",
  `2020-12-31T00:00:00Z` = "554183", `2021-01-04T00:00:00Z` = "624880",
  `2021-01-05T00:00:00Z` = "642006", `2021-01-06T00:00:00Z` = "659883",
  `2021-01-07T00:00:00Z` = "678465", `2021-01-08T00:00:00Z` = "696304",
  `2021-01-12T00:00:00Z` = "766976", `2021-01-13T00:00:00Z` = "789303",
  `2021-01-14T00:00:00Z` = "804177", `2021-01-15T00:00:00Z` = "819819",
  `2021-01-18T00:00:00Z` = "874852", `2021-01-19T00:00:00Z` = "890494",
  `2021-01-20T00:00:00Z` = "908360", `2021-01-21T00:00:00Z` = "926967",
  `2021-01-22T00:00:00Z` = "946314", `2021-01-25T00:00:00Z` = "997643",
  `2021-01-26T00:00:00Z` = "1014755", `2021-01-27T00:00:00Z` = "1033374",
  `2021-01-28T00:00:00Z` = "1053473", `2021-01-29T00:00:00Z` = "1069075",
  `2021-02-01T00:00:00Z` = "1123445", `2021-02-02T00:00:00Z` = "1140568",
  `2021-02-03T00:00:00Z` = "1160641", `2021-02-04T00:00:00Z` = "1175516",
  `2021-02-05T00:00:00Z` = "1194160"
)

pkgenv$package_versions <- new.env(parent = emptyenv())

onload_pkgcache <- function(libname, pkgname) {
  if (Sys.getenv("PKGCACHE_NO_PILLAR") == "") {
    requireNamespace("pillar", quietly = TRUE)
  }
  pkgenv$global_metadata_cache <- new.env(parent = emptyenv())
  pkgenv$archive_cache <- new.env(parent = emptyenv())
}

if (exists(".onLoad", inherits = FALSE)) {
  onload_old <- .onLoad
  .onLoad <- function(libname, pkgname) {
    onload_old(libname, pkgname)
    onload_pkgcache(libname, pkgname)
  }
} else {
  .onLoad <- onload_pkgcache
}

## nocov end

#' The R6 object that implements the global metadata cache
#'
#' This is used by the [meta_cache_deps()], [meta_cache_list()], etc.
#' functions.
#'
#' @export
#' @examplesIf FALSE
#' get_cranlike_metadata_cache()
#' get_cranlike_metadata_cache()$list("cli")

get_cranlike_metadata_cache <- function() {
  repos <- repo_get()
  hash <- cli::hash_obj_md5(repos$url)
  if (is.null(pkgenv$global_metadata_cache[[hash]])) {
    pkgenv$global_metadata_cache[[hash]] <- cranlike_metadata_cache$new()
  }
  pkgenv$global_metadata_cache[[hash]]
}
